@@ -1,5 +1,5 @@
 /*
-$Header: /cvsroot/arsperl/ARSperl/supportrev.c,v 1.22 2004/08/13 01:54:13 jcmurphy Exp $
+$Header: /cvsroot/arsperl/ARSperl/supportrev.c,v 1.24 2005/03/31 16:22:18 jeffmurphy Exp $
 
     ARSperl - An ARS v2 - v5 / Perl5 Integration Kit
 
@@ -39,6 +39,10 @@ $Header: /cvsroot/arsperl/ARSperl/supportrev.c,v 1.22 2004/08/13 01:54:13 jcmurp
 #include "support.h"
 #include "supportrev.h"
 
+/*
+ * forward declarations
+ */
+
 static int 
 rev_ARActiveLinkActionList_helper(ARControlStruct * ctrl, HV * h,
 				  ARActiveLinkActionList * al,
@@ -98,6 +102,14 @@ rev_ARPropList_helper(ARControlStruct * ctrl,
 		      HV * h, ARPropList * m, int idx);
 #endif
 
+#if AR_EXPORT_VERSION >= 4
+static int
+rev_ARMessageStruct(ARControlStruct * ctrl, 
+                    HV * h, char *k, ARMessageStruct * m);
+#endif
+
+
+
 /* ROUTINE
  *   revTypeName(TypeMapStruct *tms, char *type)
  *
@@ -825,7 +837,7 @@ rev_ARActiveLinkActionList_helper(ARControlStruct * ctrl, HV * h, ARActiveLinkAc
 		al->actionList[idx].action = AR_ACTIVE_LINK_ACTION_FIELDS;
 		rv += rev_ARFieldAssignList(ctrl, h, "assign_fields",
 #if AR_EXPORT_VERSION >= 8L
-					&(al->actionList[idx].u.setFields));
+					&(al->actionList[idx].u.setFields.fieldList));
 #else
 					&(al->actionList[idx].u.fieldList));
 #endif
@@ -1285,7 +1297,7 @@ rev_ARValueStructDiary(ARControlStruct * ctrl, HV * h, char *k, char **d)
 			if (rv == 0) {
 				int             blen = strlen(user) + strlen(value) + 2 + 12;
 				char           *buf = (char *) MALLOCNN(blen);
-				sprintf(buf, "%d\003%s\003%s", timestamp, user, value);
+				sprintf(buf, "%d\003%s\003%s", (int)timestamp, user, value);
 				*d = buf;
 				if (user)
 					AP_FREE(user);
@@ -2418,7 +2430,7 @@ rev_ARMacroParmList(ARControlStruct * ctrl, HV * h, char *k, ARMacroParmList * m
 /* roll our own strcasecmp and strncasecmp for Win */
 
 int 
-strcasecmp(const char *s1, const char *s2)
+strcasecmp(char *s1, char *s2)
 {
 	char           *p1, *p2;
 	char            c1, c2;
@@ -2438,12 +2450,12 @@ strcasecmp(const char *s1, const char *s2)
 }
 
 int 
-strncasecmp(const char *s1, const char *s2, size_t n)
+strncasecmp(char *s1, char *s2, size_t n)
 {
 
 	char           *p1, *p2;
 	char            c1, c2;
-	int             i = 0;
+	size_t          i = 0;
 	p1 = s1;
 	p2 = s2;
 
